import { IgPoint } from "igniteui-webcomponents-core";
import { Spreadsheet } from './Spreadsheet';
import { SpreadsheetAction } from './SpreadsheetAction';
import { SpreadsheetCell } from './SpreadsheetCell';
import { SpreadsheetCellEditMode } from './SpreadsheetCellEditMode';
import { SpreadsheetCellSelectionMode } from './SpreadsheetCellSelectionMode';
import { SpreadsheetChartAdapterBase } from './SpreadsheetChartAdapterBase';
import { SpreadsheetEnterKeyNavigationDirection } from './SpreadsheetEnterKeyNavigationDirection';
import { SpreadsheetPane } from './SpreadsheetPane';
import { SpreadsheetSelection } from './SpreadsheetSelection';
import { SpreadsheetCellRangeFormat } from './SpreadsheetCellRangeFormat';
import { WorksheetTable } from "igniteui-webcomponents-excel";
import { Worksheet } from "igniteui-webcomponents-excel";
import { Workbook } from "igniteui-webcomponents-excel";
import { UndoManager } from './UndoManager';
import { IgcSpreadsheetActionExecutedEventArgs } from './igc-spreadsheet-action-executed-event-args';
import { IgcSpreadsheetActionExecutingEventArgs } from './igc-spreadsheet-action-executing-event-args';
import { IgcSpreadsheetActiveCellChangedEventArgs } from './igc-spreadsheet-active-cell-changed-event-args';
import { IgcSpreadsheetActivePaneChangedEventArgs } from './igc-spreadsheet-active-pane-changed-event-args';
import { IgcSpreadsheetActiveTableChangedEventArgs } from './igc-spreadsheet-active-table-changed-event-args';
import { IgcSpreadsheetActiveWorksheetChangedEventArgs } from './igc-spreadsheet-active-worksheet-changed-event-args';
import { IgcSpreadsheetContextMenuOpeningEventArgs } from './igc-spreadsheet-context-menu-opening-event-args';
import { IgcSpreadsheetEditModeExitingEventArgs } from './igc-spreadsheet-edit-mode-exiting-event-args';
import { IgcSpreadsheetEditModeExitedEventArgs } from './igc-spreadsheet-edit-mode-exited-event-args';
import { IgcSpreadsheetEditModeEnteringEventArgs } from './igc-spreadsheet-edit-mode-entering-event-args';
import { IgcSpreadsheetEditModeEnteredEventArgs } from './igc-spreadsheet-edit-mode-entered-event-args';
import { IgcSpreadsheetEditModeValidationErrorEventArgs } from './igc-spreadsheet-edit-mode-validation-error-event-args';
import { IgcSpreadsheetEditRangePasswordNeededEventArgs } from './igc-spreadsheet-edit-range-password-needed-event-args';
import { IgcSpreadsheetHyperlinkExecutingEventArgs } from './igc-spreadsheet-hyperlink-executing-event-args';
import { IgcSpreadsheetSelectionChangedEventArgs } from './igc-spreadsheet-selection-changed-event-args';
import { IgcSpreadsheetUserPromptDisplayingEventArgs } from './igc-spreadsheet-user-prompt-displaying-event-args';
import { IgcSpreadsheetWorkbookDirtiedEventArgs } from './igc-spreadsheet-workbook-dirtied-event-args';
/**
 * Custom control that displays one or more worksheets.
*/
export declare class IgcSpreadsheetComponent extends HTMLElement {
    private _height;
    private _width;
    height: string;
    width: string;
    private _container;
    private _renderer;
    constructor();
    destroy(): void;
    private _wrapper;
    protected createImplementation(): Spreadsheet;
    private _spreadsheet;
    private _createContainer;
    private _disconnected;
    disconnectedCallback(): void;
    connectedCallback(): void;
    afterContentInit(): void;
    protected _zoneRunner: (act: () => void) => void;
    protected _runInZone(act: () => void): void;
    protected _implementation: any;
    /**
     * @hidden
     */
    readonly i: Spreadsheet; /**
                                 * @hidden
                                 */
    static _createFromInternal(internal: any): IgcSpreadsheetComponent;
    /**
     * Returns an array of the panes for the activeWorksheet.
    */
    readonly panes: SpreadsheetPane[];
    private _settingAttributes;
    protected _attached: boolean;
    private _queuedSetAttributes;
    protected _enqueueSetAttribute(attrName: string, attrValue: string): void;
    protected _flushQueuedAttributes(): void;
    protected _a(attrName: string, attrValue: any): void;
    private static _observedAttributesIgcSpreadsheetComponent;
    static readonly observedAttributes: string[];
    private _updatingFromAttribute;
    attributeChangedCallback(name: string, oldValue: string, newValue: string): void;
    static htmlTagName: string;
    protected static _isElementRegistered: boolean;
    static register(): void;
    /**
 * Returns or sets a boolean indicating whether the scroll lock key is toggled.
 * This property is used when certain keys are pressed while the control has focus. For example
 * if an arrow key is pressed while the scroll lock is enabled the cell area will be scrolled rather than changing
 * the active cell. Note: This property is not maintained/changed by the control. It is just queried when
 * performing actions that consider whether the scroll lock is enabled.
*/
    isScrollLocked: boolean;
    /**
     * Returns or sets the active cell within the selected worksheet.
    */
    activeCell: SpreadsheetCell;
    /**
     * Returns an object that represents the pane with the focus.
    */
    activePane: SpreadsheetPane;
    /**
     * Returns an object that represents the current selection of the activePane.
    */
    activeSelection: SpreadsheetSelection;
    /**
     * Returns an object used to get the formatting of the activeCell and where modifications are applied to the entire activeSelection.
     * Any changes made to this object will affect all the objects in the selection. So for example, the
     * Font.Name may return "Arial" because the active cell has that as its resolved font name even though the other
     * cells are using a different font but if you set the Font.Name of this object to "Arial" then all the objects
     * affected by the selection will have their Font.Name updated to that value.
    */
    readonly activeSelectionCellRangeFormat: SpreadsheetCellRangeFormat;
    /**
     * Returns the ig.excel.WorksheetTable associated with the activeCell of the activeWorksheet.
    */
    activeTable: WorksheetTable;
    /**
     * Returns or sets the Worksheet from the workbook whose content should be displayed within the control.
    */
    activeWorksheet: Worksheet;
    /**
     * Returns or sets a boolean indicating whether the spreadsheet allows adding worksheets.
    */
    allowAddWorksheet: boolean;
    /**
     * Returns or sets a boolean indicating whether the spreadsheet allows deleting worksheets.
    */
    allowDeleteWorksheet: boolean;
    /**
     * Returns or sets a boolean indicating if the grid lines are displayed in the selected worksheets.
    */
    areGridlinesVisible: boolean;
    /**
     * Returns or sets a boolean indicating if the row and column headers are displayed for the selected worksheets.
    */
    areHeadersVisible: boolean;
    /**
     * Returns an enumeration used to indicate the current edit mode state.
    */
    cellEditMode: SpreadsheetCellEditMode;
    /**
     * Returns or sets the object that will provide the chart visualization for display within the Spreadsheet
     * By default charts are not displayed within the spreadsheet. To display charts one should set this
     * property to an instance of a SpreadsheetChartAdapter which is in a separate reference since it relies upon
     * the chart and other data visualization controls.
    */
    chartAdapter: SpreadsheetChartAdapterBase;
    /**
     * Returns or sets an enumeration indicating the direction of the cell adjacent to the activeCell that should be activated when the enter key is pressed.
     * This property is only used if the isEnterKeyNavigationEnabled is set to true. Also, the reverse direction is
     * navigated when Shift + Enter are pressed.
    */
    enterKeyNavigationDirection: SpreadsheetEnterKeyNavigationDirection;
    /**
     * Returns or sets the number of decimal places by which a whole number typed in during edit mode should be adjusted when isFixedDecimalEnabled is true
    */
    fixedDecimalPlaceCount: number;
    /**
     * Returns or sets a boolean indicating whether the adjacent cell indicated by the enterKeyNavigationDirection should be navigated to when the enter key is pressed.
    */
    isEnterKeyNavigationEnabled: boolean;
    /**
     * Returns or sets a boolean indicating whether a fixed decimal place is automatically added when a whole number is entered while in edit mode.
    */
    isFixedDecimalEnabled: boolean;
    /**
     * Returns or sets a boolean indicating if the formula bar is displayed within the Spreadsheet.
    */
    isFormulaBarVisible: boolean;
    /**
     * Returns a boolean indicating if the control is currently editing the value of the activeCell
    */
    isInEditMode: boolean;
    /**
     * Returns or sets a boolean indicating whether the control is in "End mode".
     * End mode is a mode that affects certain keyboard navigation such as navigating with the arrow keys. For example when in
     * end mode and one presses the right arrow, the activeCell will be changed to be the first cell to the right of the current ActiveCell
     * that has a value (even if the value is ""). If there were no cells to the right with a value then it would activate the right most cell in that row. End
     * mode will end automatically such as when one presses an arrow key.
    */
    isInEndMode: boolean;
    /**
     * Returns a boolean indicating if the user is currently editing the name of the active worksheet.
    */
    isRenamingWorksheet: boolean;
    /**
     * Returns or sets a boolean indicating whether undo is enabled for the control.
    */
    isUndoEnabled: boolean;
    /**
     * Returns or sets the width of the name box within the formula bar.
    */
    nameBoxWidth: number;
    /**
     * Returns or sets a value indicating how the selection is updated when interacting with the cells via the mouse or keyboard.
    */
    selectionMode: SpreadsheetCellSelectionMode;
    /**
     * Returns or sets an array of the Worksheets whose tabs are selected.
    */
    selectedWorksheets: Worksheet[];
    /**
     * Returns or sets the UndoManager.
     * Note: this property can not be set to null.
    */
    undoManager: UndoManager;
    /**
     * Returns or sets the position of the screen tip used to display the input message for the data validation rule associated with the active cell.
    */
    validationInputMessagePosition: IgPoint;
    /**
     * Returns or sets the workbook whose information is displayed in the control.
    */
    workbook: Workbook;
    /**
     * Returns or sets the magnification of the selected worksheets.
    */
    zoomLevel: number;
    protected __p: string;
    protected _hasUserValues: Set<string>;
    protected readonly hasUserValues: Set<string>;
    protected __m(propertyName: string): void;
    protected _stylingContainer: any;
    protected _stylingParent: any;
    protected _inStyling: boolean;
    protected _styling(container: any, component: any, parent?: any): void;
    /**
 * Notifies the spreadsheet that the container object has been resized.

*/
    containerResized(): void;
    /**
     * Executes the specified action.
    
    * @param action  * Identifies the action to be performed.
    */
    executeAction(action: SpreadsheetAction): boolean;
    /**
     * Forces the spreadsheet to synchronously perform any deferred work.
    
    */
    flush(): void;
    /**
     * Notifies the spreadsheet that style information used for rendering may have been updated.
    
    */
    styleUpdated(): void;
    /**
     * Returns an object with information about the visual state of the spreadsheet.
    
    */
    exportVisualData(): any;
    private _contextMenuOpening;
    private _contextMenuOpening_wrapped;
    /**
     * Invoked when a contextmenu is being opened for the Spreadsheet.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.menuArea" argType="string" Get the [area](ig.spreadsheet.SpreadsheetContextMenuArea) for which the menu is being displayed.
    */
    contextMenuOpening: (s: IgcSpreadsheetComponent, e: IgcSpreadsheetContextMenuOpeningEventArgs) => void;
    private _CommandExecuted;
    private _CommandExecuted_wrapped;
    /**
     * Invoked when an action is executed on the Spreadsheet.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.action" argType="string" Gets the [action](ig.spreadsheet.SpreadsheetAction) that was executed.
    */
    CommandExecuted: (s: IgcSpreadsheetComponent, e: IgcSpreadsheetActionExecutedEventArgs) => void;
    private _CommandExecuting;
    private _CommandExecuting_wrapped;
    /**
     * Invoked when an action is about to be executed by the Spreadsheet.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.action" argType="string" Gets the [action](ig.spreadsheet.SpreadsheetAction) that is about to be executed.
    */
    CommandExecuting: (s: IgcSpreadsheetComponent, e: IgcSpreadsheetActionExecutingEventArgs) => void;
    private _activeCellChanged;
    private _activeCellChanged_wrapped;
    /**
     * Invoked when the activeCell of the Spreadsheet has changed.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.oldValue" argType="string" Gets the previous active cell.
     * eventArgument="ui.newValue" argType="string" Gets the current active cell.
    */
    activeCellChanged: (s: IgcSpreadsheetComponent, e: IgcSpreadsheetActiveCellChangedEventArgs) => void;
    private _activePaneChanged;
    private _activePaneChanged_wrapped;
    /**
     * Invoked when the activePane of the Spreadsheet has changed.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.oldActivePane" argType="object" Gets the previous active [pane](ig.spreadsheet.SpreadsheetPane).
     * eventArgument="ui.newActivePane" argType="object" Gets the current active [pane](ig.spreadsheet.SpreadsheetPane).
     * eventArgument="ui.activeCell" argType="string" Gets the active cell of the new active pane or null if there is no active pane.
     * eventArgument="ui.visibleRange" argType="string" Gets the current visible range of the new active pane or null if there is no active pane.
    */
    activePaneChanged: (s: IgcSpreadsheetComponent, e: IgcSpreadsheetActivePaneChangedEventArgs) => void;
    private _activeTableChanged;
    private _activeTableChanged_wrapped;
    /**
     * Invoked when the activeTable of the Spreadsheet has changed.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.oldActiveTable" argType="object" Gets the previous active [Table](ig.excel.WorksheetTable).
     * eventArgument="ui.newActiveTable" argType="object" Gets the current active [Table](ig.excel.WorksheetTable).
    */
    activeTableChanged: (s: IgcSpreadsheetComponent, e: IgcSpreadsheetActiveTableChangedEventArgs) => void;
    private _activeWorksheetChanged;
    private _activeWorksheetChanged_wrapped;
    /**
     * Invoked when the activeWorksheet of the Spreadsheet has changed.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.oldActiveWorksheet" argType="object" Gets the previous active [worksheet](ig.excel.Worksheet).
     * eventArgument="ui.oldActiveWorksheetName" argType="string" Gets the name of the previous active worksheet or null if oldActiveWorksheet is null.
     * eventArgument="ui.newActiveWorksheet" argType="object" Gets the current active [worksheet](ig.excel.Worksheet).
     * eventArgument="ui.newActiveWorksheetName" argType="string" Gets the name of the new active worksheet or null if newActiveWorksheet is null.
    */
    activeWorksheetChanged: (s: IgcSpreadsheetComponent, e: IgcSpreadsheetActiveWorksheetChangedEventArgs) => void;
    private _editModeExiting;
    private _editModeExiting_wrapped;
    /**
     * Invoked when the Spreadsheet is about to end the in-place editing of the activeCell.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.acceptChanges" argType="bool" Get or set a boolean indicating whether the changes will be made to the cell's value when edit mode ends.
     * eventArgument="ui.canCancel" argType="bool" Get a boolean indicating if the edit mode is being forced to exit edit mode in which case it cannot be cancelled.
     * eventArgument="ui.cell" argType="string" Gets the cell for which the control is exiting edit mode.
     * eventArgument="ui.editText" argType="string" Gets the edit text that will be used to update the cell(s).
    */
    editModeExiting: (s: IgcSpreadsheetComponent, e: IgcSpreadsheetEditModeExitingEventArgs) => void;
    private _editModeExited;
    private _editModeExited_wrapped;
    /**
     * Invoked when the Spreadsheet has ended the in-place editing of the activeCell.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.cell" argType="string" Gets the cell for which the control has exited edit mode.
    */
    editModeExited: (s: IgcSpreadsheetComponent, e: IgcSpreadsheetEditModeExitedEventArgs) => void;
    private _editModeEntering;
    private _editModeEntering_wrapped;
    /**
     * Invoked when the Spreadsheet is about to start in-place editing of the activeCell.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.cell" argType="string" Gets the cell for which the control is going into edit mode.
    */
    editModeEntering: (s: IgcSpreadsheetComponent, e: IgcSpreadsheetEditModeEnteringEventArgs) => void;
    private _editModeEntered;
    private _editModeEntered_wrapped;
    /**
     * Invoked when the Spreadsheet has started in-place editing of the activeCell.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.cell" argType="string" Gets the cell for which the control has entered edit mode.
    */
    editModeEntered: (s: IgcSpreadsheetComponent, e: IgcSpreadsheetEditModeEnteredEventArgs) => void;
    private _editModeValidationError;
    private _editModeValidationError_wrapped;
    /**
     * Invoked when the Spreadsheet is exiting edit mode and the new value for the activeCell is not valid based on the criteria of that cell's ig.excel.DataValidationRule.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.action" argType="string" Get or set the [action](ig.spreadsheet.SpreadsheetEditModeValidationErrorAction)  to take in response to the failed validation.
     * eventArgument="ui.canStayInEditMode" argType="bool" Get a boolean indicating whether the cell is allowed to stay in edit mode.
     * eventArgument="ui.cell" argType="string" Gets the cell for which the control is in edit mode.
     * eventArgument="ui.validationRule" argType="string" Get the [rule](ig.excel.DataValidationRule) which failed validation.
     * The EditModeValidationError is raised while exiting edit mode if the new value for the activeCell is not valid based on the criteria of that cell's ig.excel.DataValidationRule.
     * Since the rule needs to evaluate the value of the cell and potentially other cell's in the Worksheet, the value is first applied to the cell(s) and then is validated. By default if the event is not handled and the
     * showErrorMessageForInvalidValue is true, a message box will be displayed to the end user to determine what action to take. One can handle this event and specify the action that should
     * be taken using the action.Note: The validation rule will not be evaluated if edit mode is being cancelled such as when the user presses Escape to cancel edit.Note: The action will default to AcceptChange if the ShowErrorMessageForInvalidValue of the validationRule is false; otherwise it will default to ShowPrompt.Note: Like Microsoft Excel, only the validation rule of the active cell is considered even if the update is affecting other cells in the selection.
    */
    editModeValidationError: (s: IgcSpreadsheetComponent, e: IgcSpreadsheetEditModeValidationErrorEventArgs) => void;
    private _editRangePasswordNeeded;
    private _editRangePasswordNeeded_wrapped;
    /**
     * Invoked when the Spreadsheet is performing an operation on a protected Worksheet and there is a single range that may be unlocked to allow the operation to be performed.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.ranges" argType="array" Get an array of [protected range](ig.excel.WorksheetProtectedRange) objects that should be unlocked.
     * eventArgument="ui.unprotect" argType="object" Get a parameterless function that may be invoked to unlock the associated ranges.
    */
    editRangePasswordNeeded: (s: IgcSpreadsheetComponent, e: IgcSpreadsheetEditRangePasswordNeededEventArgs) => void;
    private _hyperlinkExecuting;
    private _hyperlinkExecuting_wrapped;
    /**
     * Invoked when a hyperlink is being followed in the Spreadsheet.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.hyperlink" argType="object" Get the [hyperlink](ig.excel.WorksheetHyperlink) to be executed.
    */
    hyperlinkExecuting: (s: IgcSpreadsheetComponent, e: IgcSpreadsheetHyperlinkExecutingEventArgs) => void;
    private _selectionChanged;
    private _selectionChanged_wrapped;
    /**
     * Invoked when the selection for a ig.spreadsheet.SpreadsheetPane of the Spreadsheet is changed.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.pane" argType="object" Get the [pane](ig.spreadsheet.SpreadsheetPane) for which the selection has changed.
    */
    selectionChanged: (s: IgcSpreadsheetComponent, e: IgcSpreadsheetSelectionChangedEventArgs) => void;
    private _userPromptDisplaying;
    private _userPromptDisplaying_wrapped;
    /**
     * Invoked when the user will be prompted with a message regarding an operation that is being performed.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * eventArgument="ui.canCancel" argType="bool" Get a boolean indicating if the operation that triggered the prompt can be cancelled.
     * eventArgument="ui.displayMessage" argType="bool" Get a boolean indicating if a message will be displayed to the end user.
     * eventArgument="ui.exception" argType="object" Gets the exception for the error, if there was one.
     * eventArgument="ui.message" argType="string" Get or set the message that will be displayed.
     * eventArgument="ui.trigger" argType="string" Get the [action](ig.spreadsheet.SpreadsheetUserPromptTrigger) that caused the prompt to be displayed.
    */
    userPromptDisplaying: (s: IgcSpreadsheetComponent, e: IgcSpreadsheetUserPromptDisplayingEventArgs) => void;
    private _workbookDirtied;
    private _workbookDirtied_wrapped;
    /**
     * Invoked when a change has been made to the workbook that might require a save.
     * eventArgument="evt" argType="event" jQuery event object.
     * eventArgument="ui.owner" argType="object" Gets a reference to the spreadsheet widget.
     * Note: This event is invoked asynchronously with regards to the change(s) that
     * have occurred. Also some changes alone are not considered to dirty the Workbook even though it
     * does change state on the Workbook or one of its subobjects. An example of that would be a zoom
     * type operation (e.g. changing the magnificationInNormalView).
    */
    workbookDirtied: (s: IgcSpreadsheetComponent, e: IgcSpreadsheetWorkbookDirtiedEventArgs) => void;
}
